/*
 *  SokoBan, a Sokoban game.
 *  Copyright (C) 2008  Colomban Wendling <ban@herbesfolles.org>
 * 
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */



#include <SDL/SDL.h>

#include "MYSDL_CopySurface.h"


/**
 * \brief copy a SDL_Surface
 * \param surface the surface to copy
 * \return a newly allocated SDL_Surface or NULL on error
 */
SDL_Surface * MYSDL_CopySurface (SDL_Surface *surface)
{
   SDL_Surface *copy;
   SDL_Rect bounds;
   
   if (!surface) return NULL;
   
   copy = SDL_CreateRGBSurface (surface->flags,
                                surface->w, surface->h,
                                surface->format->BitsPerPixel,
                                surface->format->Rmask,
                                surface->format->Gmask,
                                surface->format->Bmask,
                                surface->format->Amask);
   
   if (copy)
   {
      bounds.x = 0;
      bounds.y = 0;
      bounds.w = surface->w;
      bounds.h = surface->h;
      
      if (SDL_LowerBlit (surface, &bounds, copy, &bounds) < 0)
      {
         SDL_FreeSurface (copy);
         copy = NULL;
      }
   }
   
   return copy;
}
